// everything here needs to be adjusted for the deserialized json
//
#[derive(Debug, Clone)]
pub struct Message {
    pub length: u16,
    pub content: String,
}

impl Message {
    pub fn new(content: impl Into<String>) -> anyhow::Result<Self> {
        let content = content.into();
        let length = content.len() as u16;

        Ok(Self {
            length,
            content,
        })
    }

    pub fn encode(&self) -> Vec<u8> {
        let mut buffer = Vec::new();
        buffer.extend(&self.length.to_be_bytes());
        buffer.extend(self.content.as_bytes());

        buffer
    }

    pub fn decode(buffer: &[u8]) -> anyhow::Result<Self> {
        // this `if` compares the buffer length to the minimum
        // message size (which is 2 because it takes to bytes
        // to write 0), it is now hardcoded but it MUST be moved
        // into a constant in a special constant definition file
        // byeeeeeeeeeeeeeeeeee luv ya
        if buffer.len() < 2 {
            return Err(anyhow::anyhow!("Invalid message length"));
        }

        let length = u16::from_be_bytes([buffer[0], buffer[1]]);
        let content = String::from_utf8(buffer[2..2 + length as usize].to_vec())?;

        Ok(Self {
            length,
            content,
        })
    }
}
